Learn R Programming

growthmodels (version 1.3.1)

brody: Brody growth model

Description

Computes the Brody growth model and its inverse $$ y(t) = \alpha - (\alpha - w_0) exp(- k t) $$

Usage

brody(t, alpha, w0, k)

brody.inverse(x, alpha, w0, k)

Arguments

t

time

alpha

upper asymptote

w0

the value at t = 0

k

growth rate

x

size

Author

Daniel Rodriguez

References

M. M. Kaps, W. O. W. Herring, and W. R. W. Lamberson, "Genetic and environmental parameters for traits derived from the Brody growth curve and their relationships with weaning weight in Angus cattle.," Journal of Animal Science, vol. 78, no. 6, pp. 1436-1442, May 2000.

Examples

Run this code
growth <- brody(0:10, 10, 5, 0.3)

# Calculate inverse function
time <- brody.inverse(growth, 10, 5, 0.3)

Run the code above in your browser using DataLab